==> yawp-1.20.1-fabric-0.6.2-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/CrossbowItemMixin.java <==

package de.z0rdak.yawp.mixin.flag;

import de.z0rdak.yawp.api.FlagEvaluator;
import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1657;
import net.minecraft.class_1764;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;


import static de.z0rdak.yawp.api.MessageSender.sendFlagMsg;
import static de.z0rdak.yawp.core.flag.RegionFlag.FIRE_BOW;
import static de.z0rdak.yawp.handler.HandlerUtil.getDimKey;
import static de.z0rdak.yawp.handler.HandlerUtil.isServerSide;

@Mixin({class_1764.class})
public abstract class CrossbowItemMixin {
    
    @Inject(method = "use", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/CrossbowItem;performShooting(Lnet/minecraft/world/level/Level;Lnet/minecraft/world/entity/LivingEntity;Lnet/minecraft/world/InteractionHand;Lnet/minecraft/world/item/ItemStack;FF)V"), allow = 1, cancellable = true)
     public void onLooseArrow(class_1937 level, class_1657 player, class_1268 interactionHand, CallbackInfoReturnable<class_1271<class_1799>> cir) {
            FlagCheckEvent checkEvent = new FlagCheckEvent(player.method_24515(), FIRE_BOW, getDimKey(player), player);
            if (Services.EVENT.post(checkEvent)) {
                return;
            }
            FlagEvaluator.processCheck(checkEvent, denyResult -> {
                class_1799 itemStack = player.method_5998(interactionHand);
                var fail = class_1271.method_22431(itemStack);
                cir.setReturnValue(fail);
                sendFlagMsg(denyResult);
            });
    }
}

==> yawp-1.21.5-fabric-0.6.1-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/CrossbowItemMixin.java <==

package de.z0rdak.yawp.mixin.flag;

import de.z0rdak.yawp.api.FlagEvaluator;
import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1268;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_1764;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import org.jetbrains.annotations.Nullable;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;


import static de.z0rdak.yawp.api.MessageSender.sendFlagMsg;
import static de.z0rdak.yawp.core.flag.RegionFlag.FIRE_BOW;
import static de.z0rdak.yawp.handler.HandlerUtil.getDimKey;
import static de.z0rdak.yawp.handler.HandlerUtil.isServerSide;

@Mixin({class_1764.class})
public abstract class CrossbowItemMixin {
    
    @Inject(method = "performShooting", at = @At(value = "INVOKE", target = "Lnet/minecraft/world/item/ItemStack;set(Lnet/minecraft/core/component/DataComponentType;Ljava/lang/Object;)Ljava/lang/Object;"), allow = 1, cancellable = true)
    void onLooseArrow(class_1937 level, class_1309 shooter, class_1268 hand, class_1799 weapon, float velocity, float inaccuracy, @Nullable class_1309 target, CallbackInfo ci) {
        if (shooter instanceof class_1657 player) {
            FlagCheckEvent checkEvent = new FlagCheckEvent(player.method_24515(), FIRE_BOW, getDimKey(player), player);
            if (Services.EVENT.post(checkEvent)) {
                return;
            }
            FlagEvaluator.processCheck(checkEvent, denyResult -> {
                ci.cancel();
                sendFlagMsg(denyResult);
            });
        }
    }
}
